#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-55w6RUAjySMA5QiOTa3JW0
key:                  hslua-cli-1.4.3-55w6RUAjySMA5QiOTa3JW0
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  14949bf01f4bc2f2d4a969e02d153e71
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-55w6RUAjySMA5QiOTa3JW0
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-LReI2UbiKlPKhkX09mt71p
    hslua-marshalling-2.3.1-A5aoNaanlpK2FggCiFCUn4
    hslua-repl-0.1.2-FjmfJb6stdoDzCDIrDuzsY
    lua-2.3.4-4qUK93XdrXc961ve356lAJ text-2.0.2 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

